#
# spec file for package bless
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bless
Version:        0.6.3
Release:        2.9
Summary:        Gtk#-based Hex-editor written in C#
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/afrantzis/bless
Source:         https://github.com/afrantzis/bless/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool
BuildRequires:  meson >= 0.46
BuildRequires:  nunit-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glade-sharp-2.0) >= 2.8
BuildRequires:  pkgconfig(gtk-sharp-2.0) >= 2.8
BuildRequires:  pkgconfig(mono)

%description
Bless is a hex editor written in Mono/Gtk#. It features:

* Efficient editing of large data files and block devices.
* Multilevel undo - redo operations.
* Customizable data views.
* Multiple tabs.
* A data conversion table.
* Advanced copy/paste capabilities.
* Highlighting of selection pattern matches in the file.
* Plugin-based architecture.
* Export of data to text and HTML (others with plugins).
* Bitwise operations on data.

%package doc
Summary:        Documentation for Bless
Group:          Development/Tools/Other

%description doc
Bless is a hex editor.

This package contains the documentation.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%check
#System.InvalidCastException:
#%%meson_test

%files
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/bless
%{_libdir}/bless
%{_datadir}/applications/bless.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/bless

%files doc
%doc %{_datadir}/help/C/%{name}/

%changelog
* Mon Feb 28 2022 Matthias Mailänder <mailaender@opensuse.org>
- itstool is now explicitely required to build
* Mon Feb 22 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to version 0.6.3
- drop dont-require-rarian.patch
- drop bless-0.6.2-Range-ambiguous-reference.patch
* Tue Mar 17 2020 Marguerite Su <i@marguerite.su>
- update version 0.6.2
  * see git commits
- add bless-0.6.2-Range-ambiguous-reference.patch
  * Fix building error CS0104: 'Range' is an ambiguous reference
* Wed Jul 24 2019 Marguerite Su <i@marguerite.su>
- add dont-require-rarian.patch, fix boo#1141386
  * rarian/scrollkeeper is unmaintained upstream
* Sun Oct 30 2016 jengelh@inai.de
- Replace filler words by actual feature descriptions.
* Tue Oct 25 2016 mailaender@opensuse.org
- add README, COPYING/AUTHORS and ChangeLog/NEWS
* Sun Mar 20 2016 mailaender@opensuse.org
- fix download and add GPG checks
- add desktop post/un macros
- add rarian dependency
- fix build for Mono 4.0
- split documentation into sub package
* Wed May 19 2010 cdengler@suse.de
- adjust the spec-file: version to the actual one (0.6.0)
- remove http download of the package
  Sun Oct  9 00:00:00 UTC 2005 - Alexandros Frantzis <alf82 at freemail dot gr> 0.4.0
- Updated .spec file for bless-0.4.0
- All documentation now gets installed in %%{_datadir}/doc/%%{name}-%%{version}/
  instead of %%{_docdir}/%%{name}-%%{version}/
- Added post and postun actions for scrollkeeper
  Mon Sep 12 00:00:00 UTC 2005 - Mirco Mueller <macslow at bangang dot de> 0.4.0-rc1
- initial .spec file written for bless-0.4.0-rc1.tar.gz
